Bucket

Struct Bucket 

pub struct Bucket<T> { /* private fields */ }
Simple container that holds any value.

!WARNING!
If your value is zeroed, the “bucket” is considered empty.
This features probably won’t be revoked.

Implementations

Source

impl<T> Bucket<T>

pub fn new(content: T) -> Self

Creates new instance of the Bucket and takes ownership of the content.

pub fn vacate(&self) -> Option<T>

This function is used to empty the “bucket” and return the value that was inside.

If the “bucket” was empty, it returns variant None

use bucket::Bucket;

let bucket = Bucket::new("value");
assert!(bucket.vacate().is_some());

let bucket = Bucket::default();
assert!(bucket.vacate().is_none());  // Returns none, because our bucket is created without any content
pub fn peek_ref(&self) -> Option<&T>

Returns a reference to the content value if the “bucket” is filled.

use bucket::Bucket;

let bucket = Bucket::new(5);
println!("{}", bucket.peek_ref());
assert!(bucket.vacate().is_some());
pub fn peek_mut(&self) -> Option<&mut T>

Returns a mutable reference to the content value if the “bucket” is filled.

use bucket::Bucket;

let bucket = Bucket::new(vec![1, 2, 3]);
for number in bucket.peek_mut().unwrap() {
    *number += 1;
}
pub fn fill(&self, content: T) -> Option<T>

This function is used to fill the “bucket” with a desired value.
If “bucket” is already filled, it returns provided value.

use bucket::Bucket;

let bucket = Bucket::default();
bucket.fill(5);
assert_eq!(bucket.fill(6), Some(6));
pub fn is_empty(&self) -> bool

Checks if the “bucket” is empty (zeroed).